<?php
/* ======================================================
 # Virtuemart Sales for Joomla! - v7.1.8 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v4.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://demo.web357.com/joomla/virtuemart-sales
 # Support: support@web357.com
 # Last modified: Monday 10 July 2023, 03:54:31 AM
 ========================================================= */
// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

class VMSalesViewVMSales extends JViewLegacy
{
	protected $items;
	protected $pagination;
	protected $state;
	protected $params;

	public function display($tpl = null)
	{
		if (!defined("DS")):
			define("DS", DIRECTORY_SEPARATOR);
		endif;
		
		$app = JFactory::getApplication();
		$this->document = JFactory::getDocument();
		$menu = JFactory::getApplication()->getMenu();
		$active = $menu->getActive();

		// BEGIN: Load VirtueMart's Api
		$this->state      						= $this->get('State');
		$this->items 	  						= $this->get('Items');
		$this->total 	  						= (int) $this->get('Total');
		$this->products_with_discount_arr 		= $this->get('ProductsWithDiscount');
		$this->products_without_discount_arr 	= $this->get('ProductsWithoutDiscount');
		$this->manufacturers_list 				= $this->get('Manufacturers');
		$this->category_list_tree 				= $this->get('Categories');
		$this->currency_helper	 				= $this->get('CurrencyHelper');
		$this->pagination 						= $this->get('Pagination');
		$this->params     						= $app->getParams('com_vmsales');
		$this->filterForm 						= $this->get('FilterForm');

		// ***** BEGIN: Get Params ***** 
		$this->data_type						= $this->params->get('data_type', 'all');
		$this->display_pagination				= $this->params->get('display_pagination', '1');
		$this->limit_of_products_per_page 		= $this->params->get('limit_of_products_per_page', '30');
        $this->search_text 						= $this->params->get('search_text', '0');
		$this->search_categories 				= $this->params->get('search_categories', '0');
		$this->search_manufacturers 			= $this->params->get('search_manufacturers', '0');
		$this->search_type 						= $this->params->get('search_type', '0');
		$this->search_sort_by 					= $this->params->get('search_sort_by', '0');
		$this->share_button 					= $this->params->get('share_button', '1');
		$this->question_link 					= $this->params->get('question_link', '1');
		$this->view_more_button 				= $this->params->get('view_more_button', '1');
		$this->view_description 				= $this->params->get('view_description', '1');
		$this->title_chars_limit 				= $this->params->get('title_chars_limit', '0');
		$this->description_type 				= $this->params->get('description_type', 'short');
		$this->description_chars_limit 			= $this->params->get('description_chars_limit', '100');
		$this->allowed_html_tags 				= $this->params->get('allowed_html_tags', '');
		$this->image_click 						= $this->params->get('image_click', 'link_to_product');
		$this->display_price_with_tax 			= $this->params->get('display_price_with_tax', '0');	
		$this->discount_type_display 			= $this->params->get('discount_type_display', 'percentage_discount');	
		$this->display_only_featured_products 	= $this->params->get('display_only_featured_products', '0');
        $this->num_of_products_per_row 			= $this->params->get('num_of_products_per_row', '1');
		$this->copyright 						= $this->params->get('copyright', '1');
		// ***** END: Get Params ***** 

		// Get Page Heading
		$menu 			= JFactory::getApplication()->getMenu();
		$active 		= $menu->getActive();
		$page_heading 	= $active->params->get('page_heading');
		$this->heading 	= (!empty($page_heading)) ? $page_heading : JFactory::getDocument()->getTitle();

		// menu item
		$menu_item					= JFactory::getApplication()->getMenu()->getItems( 'link', 'index.php?option=vmsales&view=vmsales', true );
		$default_menu_item_id		= (!empty($menu_item)) ? $menu_item->id : '';
		$menu_item_id				= JFactory::getApplication()->input->get('Itemid', $default_menu_item_id, 'INT');
		$this->menu_item_id_value	= (int) (!empty($menu_item_id)) ? $menu_item_id : '';
		$this->menu_item_id			= (!empty($menu_item_id)) ? '&Itemid='.$menu_item_id : '';

		// ssl URLs
		$congfig_forse_ssl = JFactory::getConfig()->get( 'config.force_ssl' ); // 0 = disabled, 1 = Administrator Only, 2 = Entire Site
		$this->congfig_forse_ssl = ($congfig_forse_ssl == 0 || empty($congfig_forse_ssl)) ? 0 : 1;
		
		// Search input
		$filters = $this->filterForm->getGroup('filter');
		$filter_search = $filters['filter_search'];
		$this->search_input = $filter_search->input;

		// Filter Data Type
		$options = array();
		$options[0] = new stdClass();
		$options[0]->value = "with_discount";
		$options[0]->text = JText::_('VMSALES_PRODUCTS_WITH_DISCOUNT');
		$options[1] = new stdClass();
		$options[1]->value = "without_discount";
		$options[1]->text = JText::_('VMSALES_PRODUCTS_WITHOUT_DISCOUNT');
		$options[2] = new stdClass();
		$options[2]->value = "all";
		$options[2]->text = JText::_('VMSALES_ALL_PRODUCTS');
		$this->datatype_list = JHTML::_( 'select.genericlist',
                    $options, 
                    'filter[datatype]', 
					'class="uk-select ma-select"',
                    'value', 
					'text', 
					$this->getState('filter.datatype'), 
					'filter_datatype', 
					true);
				
		// Filter Ordering
		$options = array();
		$options[0] = new stdClass();
		$options[0]->value = "";
		$options[0]->text = JText::_('VMSALES_DEFAULT');
		$options[1] = new stdClass();
		$options[1]->value = "most_recent_first";
		$options[1]->text = JText::_('VMSALES_NEW_PRODUCTS');
		$options[2] = new stdClass();
		$options[2]->value = "oldest_first";
		$options[2]->text = JText::_('VMSALES_OLDEST_FIRST');
		$options[3] = new stdClass();
		$options[3]->value = "discount_high_to_low";
		$options[3]->text = JText::_('VMSALES_DISCOUNT_HIGH_TO_LOW');
		$options[4] = new stdClass();
		$options[4]->value = "discount_low_to_high";
		$options[4]->text = JText::_('VMSALES_DISCOUNT_LOW_TO_HIGH');
		$options[5] = new stdClass();
		$options[5]->value = "price_high_to_low";
		$options[5]->text = JText::_('VMSALES_PRICE_HIGH_TO_LOW');
		$options[6] = new stdClass();
		$options[6]->value = "price_low_to_high";
		$options[6]->text = JText::_('VMSALES_PRICE_LOW_TO_HIGH');
		$options[7] = new stdClass();
		$options[7]->value = "weight_high_to_low";
		$options[7]->text = JText::_('VMSALES_WEIGHT_HIGH_TO_LOW');
		$options[8] = new stdClass();
		$options[8]->value = "weight_low_to_high";
		$options[8]->text = JText::_('VMSALES_WEIGHT_LOW_TO_HIGH');

		$this->orderby_list = JHTML::_( 'select.genericlist',
                    $options, 
                    'filter[orderby]', 
					'class="uk-select ma-select"',
                    'value', 
					'text', 
					$this->getState('filter.orderby'), 
					'filter_orderby', 
					true);

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}

		$this->_prepareDocument();
		parent::display($tpl);
	}

	/**
	 * Prepares the document
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	protected function _prepareDocument()
	{
		$app   = JFactory::getApplication();
		$menus = $app->getMenu();
		$title = null;

		// Because the application sets a default page title,
		// we need to get it from the menu item itself
		$menu = $menus->getActive();

		if ($menu)
		{
			$this->params->def('page_heading', $this->params->get('page_title', $menu->title));
		}
		else
		{
			$this->params->def('page_heading', JText::_('COM_STARTUP_DEFAULT_PAGE_TITLE'));
		}

		$title = $this->params->get('page_title', '');

		if (empty($title))
		{
			$title = $app->get('sitename');
		}
		elseif ($app->get('sitename_pagetitles', 0) == 1)
		{
			$title = JText::sprintf('JPAGETITLE', $app->get('sitename'), $title);
		}
		elseif ($app->get('sitename_pagetitles', 0) == 2)
		{
			$title = JText::sprintf('JPAGETITLE', $title, $app->get('sitename'));
		}

		$this->document->setTitle($title);

		if ($this->params->get('menu-meta_description'))
		{
			$this->document->setDescription($this->params->get('menu-meta_description'));
		}

		if ($this->params->get('menu-meta_keywords'))
		{
			$this->document->setMetadata('keywords', $this->params->get('menu-meta_keywords'));
		}

		if ($this->params->get('robots'))
		{
			$this->document->setMetadata('robots', $this->params->get('robots'));
		}
	}

	/**
	 * Check if state is set
	 *
	 * @param   mixed  $state  State
	 *
	 * @return bool
	 */
	public function getState($state)
	{
		return isset($this->state->{$state}) ? $this->state->{$state} : false;
	}

}